==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/ColumnFilterConditionGroupDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnFilterConditionDescriptionMetadata } from "./ColumnFilterConditionDescriptionMetadata";
import { ColumnFilterConditionGroupDescription } from "./ColumnFilterConditionGroupDescription";
/**
 * @hidden
 */
export let ColumnFilterConditionGroupDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnFilterConditionGroupDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnFilterConditionGroupDescriptionMetadata.a == null) {
                ColumnFilterConditionGroupDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnFilterConditionGroupDescriptionMetadata.c(ColumnFilterConditionGroupDescriptionMetadata.a);
            }
            if (a.j(ColumnFilterConditionGroupDescriptionMetadata.a)) {
                return;
            }
            a.y(ColumnFilterConditionGroupDescriptionMetadata.a);
            ColumnFilterConditionDescriptionMetadata.d(a);
        }
        static c(a) {
            ColumnFilterConditionDescriptionMetadata.c(a);
            a.item("UsesOrOperator", "Boolean");
            a.item("Item", "(w:this[],wf:this[])ExportedType:ColumnFilterCondition");
        }
        static d(a) {
            ColumnFilterConditionGroupDescriptionMetadata.b(a);
            a.aa("ColumnFilterConditionGroup", () => new ColumnFilterConditionGroupDescription());
            a.z("ColumnFilterConditionGroup", ColumnFilterConditionGroupDescriptionMetadata.a);
        }
    }
    ColumnFilterConditionGroupDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnFilterConditionGroupDescriptionMetadata, 'ColumnFilterConditionGroupDescriptionMetadata');
    ColumnFilterConditionGroupDescriptionMetadata.a = null;
    return ColumnFilterConditionGroupDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ColumnFilterConditionGroupDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ColumnFilterConditionDescriptionMetadata } from "./ColumnFilterConditionDescriptionMetadata";
import { ColumnFilterConditionGroupDescription } from "./ColumnFilterConditionGroupDescription";
/**
 * @hidden
 */
export let ColumnFilterConditionGroupDescriptionMetadata = /*@__PURE__*/ (() => {
    class ColumnFilterConditionGroupDescriptionMetadata extends Base {
        static b(a) {
            if (ColumnFilterConditionGroupDescriptionMetadata.a == null) {
                ColumnFilterConditionGroupDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ColumnFilterConditionGroupDescriptionMetadata.c(ColumnFilterConditionGroupDescriptionMetadata.a);
            }
            if (a.k(ColumnFilterConditionGroupDescriptionMetadata.a)) {
                return;
            }
            a.aa(ColumnFilterConditionGroupDescriptionMetadata.a);
            ColumnFilterConditionDescriptionMetadata.d(a);
        }
        static c(a) {
            ColumnFilterConditionDescriptionMetadata.c(a);
            a.item("UsesOrOperator", "Boolean");
            a.item("Item", "(w:this[],wf:this[])ExportedType:ColumnFilterCondition");
        }
        static d(a) {
            ColumnFilterConditionGroupDescriptionMetadata.b(a);
            a.ac("ColumnFilterConditionGroup", () => new ColumnFilterConditionGroupDescription());
            a.ab("ColumnFilterConditionGroup", ColumnFilterConditionGroupDescriptionMetadata.a);
        }
    }
    ColumnFilterConditionGroupDescriptionMetadata.$t = /*@__PURE__*/ markType(ColumnFilterConditionGroupDescriptionMetadata, 'ColumnFilterConditionGroupDescriptionMetadata');
    ColumnFilterConditionGroupDescriptionMetadata.a = null;
    return ColumnFilterConditionGroupDescriptionMetadata;
})();
